@@ -13,7 +13,7 @@ from .basehist import BaseHist
 from .hist import Hist
 from .namedhist import NamedHist
 from .stack import Stack
-from .tag import (  # pylint: disable=redefined-builtin
+from .tag import (
     loc,
     overflow,
     rebin,
@@ -52,9 +52,8 @@ def __dir__() -> tuple[str, ...]:
 
 
 def __getattr__(name: str) -> ModuleType:
-
     if name == "axes":
         msg = f"Misspelling error, '{name}' should be 'axis'"
-        warnings.warn(msg)
+        warnings.warn(msg, stacklevel=2)
         return axis
     raise AttributeError(f"module {__name__} has no attribute {name}")
