@@ -3,11 +3,6 @@ from __future__ import annotations
 import sys
 from typing import TYPE_CHECKING, Any
 
-if sys.version_info < (3, 8):
-    from typing_extensions import Literal, Protocol, SupportsIndex
-else:
-    from typing import Literal, Protocol, SupportsIndex
-
 if sys.version_info < (3, 11):
     from typing_extensions import Self
 else:
@@ -21,7 +16,7 @@ else:
     Ufunc = Any
 
 
-__all__ = ["Literal", "Protocol", "SupportsIndex", "Ufunc", "ArrayLike", "Self"]
+__all__ = ["Ufunc", "ArrayLike", "Self"]
 
 
 def __dir__() -> list[str]:
