@@ -44,7 +44,7 @@ class NamedAxesTuple(AxesTuple):
         """
         The names of the axes. May be empty strings.
         """
-        return tuple(ax.name for ax in self)  # type: ignore[return-value]
+        return tuple(ax.name for ax in self)
 
     @name.setter
     def name(self, values: Iterable[str]) -> None:
@@ -72,4 +72,4 @@ class NamedAxesTuple(AxesTuple):
         The labels of the axes. Defaults to name if label not given, or Axis N
         if neither was given.
         """
-        return tuple(ax.label for ax in self)  # type: ignore[return-value]
+        return tuple(ax.label for ax in self)
