@@ -1,13 +1,14 @@
 from __future__ import annotations
 
-from typing import Any, Iterable
+import typing
+from collections.abc import Iterable
+from typing import Any, Protocol
 
 import boost_histogram as bh
 import boost_histogram.axis as bha
 
 import hist
 
-from .._compat.typing import Protocol
 from ..axestuple import ArrayTuple, NamedAxesTuple
 from . import transform
 
@@ -38,8 +39,7 @@ class AxisProtocol(Protocol):
     metadata: Any
 
     @property
-    def name(self) -> str:
-        ...
+    def name(self) -> str: ...
 
     label: str
     _ax: CoreAxisProtocol
@@ -57,7 +57,7 @@ class AxesMixin:
         """
         Get the name for the Regular axis
         """
-        return self._ax.metadata.get("name", "")
+        return typing.cast(str, self._ax.metadata.get("name", ""))
 
     @property
     def label(self: AxisProtocol) -> str:
