@@ -4,7 +4,18 @@ import functools
 import operator
 import typing
 import warnings
-from typing import Any, Callable, Generator, Iterator, Mapping, Sequence, Tuple, Union
+from typing import (
+    Any,
+    Callable,
+    Generator,
+    Iterator,
+    Mapping,
+    Protocol,
+    Sequence,
+    SupportsIndex,
+    Tuple,
+    Union,
+)
 
 import boost_histogram as bh
 import histoprint
@@ -13,7 +24,7 @@ import numpy as np
 import hist
 
 from . import interop
-from ._compat.typing import ArrayLike, Protocol, Self, SupportsIndex
+from ._compat.typing import ArrayLike, Self
 from .axestuple import NamedAxesTuple
 from .axis import AxisProtocol
 from .quick_construct import MetaConstructor
@@ -30,8 +41,7 @@ if typing.TYPE_CHECKING:
 
 
 class SupportsLessThan(Protocol):
-    def __lt__(self, __other: Any) -> bool:
-        ...
+    def __lt__(self, __other: Any) -> bool: ...
 
 
 InnerIndexing = Union[
@@ -231,6 +241,13 @@ class BaseHist(bh.Histogram, metaclass=MetaConstructor, family=hist):
         a Hist object.
         """
 
+        if (
+            issubclass(self.storage_type, (bh.storage.Mean, bh.storage.WeightedMean))
+            and sample is None
+        ):
+            msg = "A Mean-based storage requires a sample= argument with the values to average"
+            raise TypeError(msg)
+
         data_dict = {
             self._name_to_index(k) if isinstance(k, str) else k: v  # type: ignore[redundant-expr]
             for k, v in kwargs.items()
@@ -496,8 +513,9 @@ class BaseHist(bh.Histogram, metaclass=MetaConstructor, family=hist):
             (overlay,) = (i for i, ax in enumerate(self.axes) if ax.traits.discrete)
         assert overlay is not None
         cat_ax = self.axes[overlay]
-        cats = cat_ax if cat_ax.traits.discrete else np.arange(len(cat_ax.centers))
-        d1hists = [self[{overlay: cat}] for cat in cats]
+        icats = np.arange(len(cat_ax))
+        cats = cat_ax if cat_ax.traits.discrete else icats
+        d1hists = [self[{overlay: cat}] for cat in icats]
         if "label" in kwargs:
             if not isinstance(kwargs["label"], str) and len(kwargs["label"]) == len(
                 cats
