@@ -1,11 +1,9 @@
 from __future__ import annotations
 
-from typing import Any
+from typing import Any, Literal
 
 import numpy as np
 
-from ._compat.typing import Literal
-
 try:
     from scipy import stats
 except ModuleNotFoundError:
