@@ -2,14 +2,12 @@ from __future__ import annotations
 
 import inspect
 import sys
-from typing import Any, Callable, Iterable, NamedTuple, Union
+from typing import Any, Callable, Iterable, Literal, NamedTuple, Union
 
 import numpy as np
 
 import hist
 
-from ._compat.typing import Literal
-
 try:
     import matplotlib.axes
     import matplotlib.pyplot as plt
@@ -122,7 +120,7 @@ def _expr_to_lambda(expr: str) -> Callable[..., Any]:
     varnames = list(OrderedDict.fromkeys([name for name in varnames if name != "x"]))
     lambdastr = f"lambda x,{','.join(varnames)}: {expr}"
     # pylint: disable-next=eval-used
-    return eval(lambdastr)  # type: ignore[no-any-return]  # noqa: PGH001
+    return eval(lambdastr)  # type: ignore[no-any-return]
 
 
 def _curve_fit_wrapper(
@@ -193,7 +191,7 @@ def _plot_keywords_wrapper(ax: matplotlib.axes.Axes, legend: bool | None) -> Non
     # Todo: more keywords here
     if legend:
         if ax.get_legend_handles_labels()[0]:
-            legend = ax.legend()
+            ax.legend()
         else:
             raise ValueError("No labels to legend")
 
@@ -517,7 +515,8 @@ def plot_pull_array(
             downRect_startpoint, patch_width, patch_height, **pp_kwargs
         )
         ax.add_patch(downRect)
-        patch_artists.append((downRect, upRect))
+        patch_artists.append(downRect)
+        patch_artists.append(upRect)
 
     ax.set_xlim(left_edge, right_edge)
 
