@@ -1,11 +1,12 @@
 from __future__ import annotations
 
-from ._compat.typing import Protocol, Self
+from typing import Protocol
+
+from ._compat.typing import Self
 
 
 class SupportsStr(Protocol):
-    def __str__(self) -> str:
-        ...
+    def __str__(self) -> str: ...
 
 
 class XML:
